@@ -27,13 +27,12 @@ template<class Key, class Val>
 class PrioQueue {
 	typedef std::pair<Key, Val> ElemType;
 
-protected:
+private:
 	std::set<ElemType> pqset;
 	std::vector<Key> mapValToKey;
 
 	const Key undefined = std::numeric_limits<Key>::max(); // TODO: make static
 
-
 public:
 	/**
 	 * Builds priority queue from the vector @a elems.
