@@ -16,4 +16,9 @@ namespace NetworKit {
 		return "Algorithm base class";
 	}
 
-} /* NetworKit */
\ No newline at end of file
+	bool Algorithm::isParallel() const {
+		throw std::runtime_error("TODO: Implement in subclass");
+		return false;
+	}
+
+} /* NetworKit */
