@@ -39,8 +39,13 @@ public:
 	 * @return The string representation of the algorithm.
 	 */
 	virtual std::string toString() const;
+
+	/**
+	 * @return True if algorithm can run multi-threaded. 
+	 */
+	virtual bool isParallel() const;
 };
 
 } /* NetworKit */
 
-#endif /* ALGORITHM_H */
\ No newline at end of file
+#endif /* ALGORITHM_H */
