@@ -2,13 +2,14 @@
  * Centrality.h
  *
  *  Created on: 19.02.2014
- *      Author: cls
+ *      Author: Christian Staudt
  */
 
 #ifndef CENTRALITY_H_
 #define CENTRALITY_H_
 
 #include "../graph/Graph.h"
+#include "../base/Algorithm.h"
 
 namespace NetworKit {
 
@@ -16,7 +17,7 @@ namespace NetworKit {
  * @ingroup centrality
  * Abstract base class for centrality measures.
  */
-class Centrality {
+class Centrality : public Algorithm {
 public:
 	/**
 	 * Constructs the Centrality class for the given Graph @a G. If the betweenness scores should be normalized,
@@ -24,8 +25,9 @@ public:
 	 *
 	 * @param G The graph.
 	 * @param normalized If set to @c true the scores are normalized in the interval [0,1].
+	 * @param computeEdgeCentrality		If true, compute also edge centralities (for algorithms where this is applicable)
 	 */
-	Centrality(const Graph& G, bool normalized=false);
+	Centrality(const Graph& G, bool normalized=false, bool computeEdgeCentrality=false);
 
 	/** Default destructor */
 	virtual ~Centrality() = default;
@@ -41,6 +43,12 @@ public:
 	 */
 	virtual std::vector<double> scores();
 
+	/**
+	 * Get a vector containing the edge betweenness score for each edge in the graph.
+	 * @return The edge betweenness scores calculated by @link run().
+	 */
+	virtual std::vector<double> edgeScores();
+
 	/**
 	 * Get a vector of pairs sorted into descending order. Each pair contains a node and the corresponding score
 	 * calculated by @link run().
@@ -67,8 +75,9 @@ protected:
 
 	const Graph& G;
 	std::vector<double> scoreData;
+	std::vector<double> edgeScoreData;
 	bool normalized; // true if scores should be normalized in the interval [0,1]
-
+	bool computeEdgeCentrality;
 
 };
 
