@@ -19,7 +19,7 @@ namespace NetworKit {
 
 DynApproxBetweenness::DynApproxBetweenness(const Graph& G, double epsilon, double delta, bool storePredecessors) : Centrality(G, true),
 storePreds(storePredecessors), epsilon(epsilon), delta(delta) {
-
+  INFO("Constructing DynApproxBetweenness. storePredecessors = ", storePredecessors);
 }
 
 
@@ -29,6 +29,7 @@ count DynApproxBetweenness::getNumberOfSamples() {
 
 
 void DynApproxBetweenness::run() {
+  INFO("Inside DynApproxBetweenness. storePreds = ", storePreds);
     if (G.isDirected()) {
         throw std::runtime_error("Invalid argument: G must be undirected.");
     }
@@ -60,19 +61,27 @@ void DynApproxBetweenness::run() {
             v[i] = Sampling::randomNode(G);
         } while (v[i] == u[i]);
         if (G.isWeighted()) {
+            INFO("Calling DynDijkstra inside run DynApproxBet");
             sssp[i].reset(new DynDijkstra(G, u[i], storePreds));
         } else {
+            INFO("Calling DynBFS inside run DynApproxBet");
             sssp[i].reset(new DynBFS(G, u[i], storePreds));
         }
         DEBUG("running shortest path algorithm for node ", u[i]);
+
+        INFO("Calling setTargetNodeon sssp instance inside run DynApproxBet");
         sssp[i]->setTargetNode(v[i]);
+        INFO("Calling run on sssp instance inside run DynApproxBet");
         sssp[i]->run();
+        INFO("Ran sssp");
         if (sssp[i]->distances[v[i]] > 0) { // at least one path between {u, v} exists
             DEBUG("updating estimate for path ", u[i], " <-> ", v[i]);
+            INFO("Entered if statement.");
             // random path sampling and estimation update
             sampledPaths[i].clear();
             node t = v[i];
             while (t != u[i])  {
+              INFO("Entered while statement");
                 // sample z in P_u(t) with probability sigma_uz / sigma_us
                 std::vector<std::pair<node, double> > choices;
                 if (storePreds) {
@@ -86,10 +95,13 @@ void DynApproxBetweenness::run() {
                     }
                 }
                 else {
-                G.forInEdgesOf(t, [&](node t, node z, edgeweight w){
+                  INFO("Storepreds is false");
+                  G.forInEdgesOf(t, [&](node t, node z, edgeweight w){
                         if (Aux::NumericTools::logically_equal(sssp[i]->distances[t], sssp[i]->distances[z] + w)) {
                             // workaround for integer overflow in large graphs
+                            INFO("Calling number of paths");
                             bigfloat tmp = sssp[i]->numberOfPaths(z) / sssp[i]->numberOfPaths(t);
+                            INFO("Called number of paths");
                             double weight;
                             tmp.ToDouble(weight);
 
