@@ -9,7 +9,11 @@
 
 namespace NetworKit {
 
-std::pair<Graph, std::vector<node> > MatchingContracter::run(Graph& G, Matching& M, bool noSelfLoops) {
+MatchingContracter::MatchingContracter(const Graph& G, const Matching& M, bool noSelfLoops) : GraphCoarsening(G), M(M), noSelfLoops(noSelfLoops) {
+
+}
+
+void MatchingContracter::run() {
 	count n = G.numberOfNodes();
 	index z = G.upperNodeIdBound();
 	count cn = n - M.size();
@@ -37,17 +41,17 @@ std::pair<Graph, std::vector<node> > MatchingContracter::run(Graph& G, Matching&
 //	std::cout << "matching size: " << M.matchingSize() << std::endl;
 
 	G.forNodes([&](node v) { // TODO: difficult in parallel
-		G.forNeighborsOf(v, [&](node u) {
+		G.forNeighborsOf(v, [&](node u, edgeweight ew) {
 			node cv = mapFineToCoarse[v];
 			node cu = mapFineToCoarse[u];
-			edgeweight ew = G.weight(v, u);
 			if (! noSelfLoops || (cv != cu)) {
-				cG.setWeight(cv, cu, cG.weight(cv, cu) + ew);
+				cG.increaseWeight(cv, cu, ew);
 			}
 		});
 	});
 
-	return std::make_pair(cG, mapFineToCoarse);
+	Gcoarsed = std::move(cG);
+	nodeMapping = std::move(mapFineToCoarse);
 }
 
 } /* namespace NetworKit */
