@@ -89,6 +89,14 @@ std::vector<GraphEvent> NetworKit::DGSStreamParser::getStream() {
 				auto ev = GraphEvent(GraphEvent::EDGE_WEIGHT_UPDATE, u, v, w);
 				// TRACE(ev.toString());
 				stream.push_back(ev);
+			} else if (tag.compare("ie") == 0) { // update edge. Only the "weight" attribute is supported so far
+				std::vector<std::string> uvs = Aux::StringTools::split(split[1], '-');
+				node u = map(uvs[0]);
+				node v = map(uvs[1]);
+				edgeweight w = std::stod(Aux::StringTools::split(split[2], '=')[1]); // weight=<w>
+				auto ev = GraphEvent(GraphEvent::EDGE_WEIGHT_INCREMENT, u, v, w);
+				// TRACE(ev.toString());
+				stream.push_back(ev);
 			} else if (tag.compare("de") == 0) {
 				std::vector<std::string> uvs = Aux::StringTools::split(split[1], '-');
 				node u = map(uvs[0]);
@@ -101,7 +109,14 @@ std::vector<GraphEvent> NetworKit::DGSStreamParser::getStream() {
 				auto ev = GraphEvent(GraphEvent::NODE_REMOVAL, u);
 				// TRACE(ev.toString());
 				stream.push_back(ev);
-			} else {
+			} else if (tag.compare("rn") == 0) {
+				node u = map(split[1]);
+				auto ev = GraphEvent(GraphEvent::NODE_RESTORATION, u);
+				// TRACE(ev.toString());
+				stream.push_back(ev);
+			}
+
+				else {
 				ERROR("malformed line (" , lc , ") : " , line);
 				throw std::runtime_error("malformed line in .DGS file");
 			}
@@ -141,6 +156,13 @@ std::vector<GraphEvent> NetworKit::DGSStreamParser::getStream() {
 				edgeweight w = std::stod(Aux::StringTools::split(split[2], '=')[1]); // weight=<w>
 				stream.push_back(GraphEvent(GraphEvent::EDGE_WEIGHT_UPDATE, u, v, w));
 				// TRACE("read: ce ", u, ",", v, ",", w);
+			} else if (tag.compare("ie") == 0) { // update edge. Only the "weight" attribute is supported so far
+				std::vector<std::string> uvs = Aux::StringTools::split(split[1], '-');
+				node u = offset(std::stoul(uvs[0]));
+				node v = offset(std::stoul(uvs[1]));
+				edgeweight w = std::stod(Aux::StringTools::split(split[2], '=')[1]); // weight=<w>
+				stream.push_back(GraphEvent(GraphEvent::EDGE_WEIGHT_INCREMENT, u, v, w));
+				// TRACE("read: ce ", u, ",", v, ",", w);
 			} else if (tag.compare("de") == 0) {
 				std::vector<std::string> uvs = Aux::StringTools::split(split[1], '-');
 				node u = offset(std::stoul(uvs[0]));
@@ -151,7 +173,12 @@ std::vector<GraphEvent> NetworKit::DGSStreamParser::getStream() {
 				node u = offset(std::stoul(split[1]));
 				stream.push_back(GraphEvent(GraphEvent::NODE_REMOVAL, u));
 				// TRACE("read: dn ", u);
-			} else {
+			} else if (tag.compare("rn") == 0) {
+				node u = offset(std::stoul(split[1]));
+				stream.push_back(GraphEvent(GraphEvent::NODE_RESTORATION, u));
+				TRACE("read: rn ", u);
+			}
+			  else {
 				ERROR("malformed line (" , lc , ") : " , line);
 				throw std::runtime_error("malformed line in .DGS file");
 			}
@@ -167,4 +194,3 @@ std::vector<GraphEvent> NetworKit::DGSStreamParser::getStream() {
 
 
 } /* namespace NetworKit */
-
