@@ -20,9 +20,16 @@ void EdgeListWriter::write(const Graph& G, std::string path) {
     std::ofstream file(path);
     Aux::enforceOpened(file);
 
-    G.forEdges([&](node u, node v){
-    	file << (u + firstNode) << separator << (v + firstNode) << std::endl;
-    });
+    if (G.isWeighted()) {
+        G.forEdges([&](node u, node v, double weight){
+            file << (u + firstNode) << separator << (v + firstNode) << weight << std::endl;
+        });
+    } else {
+        G.forEdges([&](node u, node v){
+        	file << (u + firstNode) << separator << (v + firstNode) << std::endl;
+        });
+    }
+
 
     file.close();
 
