@@ -9,6 +9,8 @@
 #define DIAMETER_H_
 
 #include "../graph/Graph.h"
+#include "../auxiliary/SignalHandling.h"
+
 
 namespace NetworKit {
 
@@ -57,6 +59,11 @@ public:
 			Considers each connected component and returns the maximum diameter.
 	 */
 	static edgeweight estimatedVertexDiameterPedantic(const Graph& G);
+
+	/** @return a 2-approximation of the vertex diameter (unweighted diameter) of @a G.
+			Considers each connected component and returns the maximum diameter.
+	*/
+	static edgeweight estimatedVertexDiameterPedantic2(const Graph& G);
 };
 
 } /* namespace NetworKit */
