@@ -7,7 +7,7 @@ from networkit import *
 class Test_CommunityDetection(unittest.TestCase):
 
 	def setUp(self):
-		self.G = readGraph("PGPgiantcompo.graph",Format.METIS)
+		self.G = readGraph("input/PGPgiantcompo.graph",Format.METIS)
 
 	def test_PLM(self):
 		comms = community.detectCommunities(self.G, community.PLM(self.G))
@@ -17,7 +17,7 @@ class Test_CommunityDetection(unittest.TestCase):
 			self.assertTrue(comms.contains(v))
 
 	def test_CutClustering(self):
-		jazz = readGraph("jazz.graph",Format.METIS)
+		jazz = readGraph("input/jazz.graph",Format.METIS)
 
 		cc = community.CutClustering(jazz,0.5076142131979697)
 
@@ -26,3 +26,4 @@ class Test_CommunityDetection(unittest.TestCase):
 
 		hierarchy = community.CutClustering.getClusterHierarchy(jazz)
 		self.assertEqual(3, len(hierarchy))
+
